(io)=

# I/O

This module include I/O related functionality.

(iomodule)=

## io_handler

```{eval-rst}
.. automodule:: io_operations.io_handler
   :members:
```

(iohdf5)=

## hdf5_handler

```{eval-rst}
.. automodule:: io_operations.hdf5_handler
   :members:
```

(legacy-data-handler)-

## legacy_data_handler

```{eval-rst}
.. automodule:: io_operations.legacy_data_handler
   :members:
```
